@@ -16,11 +16,13 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 from datetime import datetime
+import uuid
 
 
 class AttackEvent(object):
     def __init__(self):
-        self.sensor_add = ("127.0.0.1", "8080")
+        self.id = str(uuid.uuid4())
+        self.sensor_addr = ("", "")
         self.http_request = None
         self.raw_request = None
         self.event_time = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
