@@ -24,9 +24,7 @@ class FaviconHandler(base_emulator.BaseEmulator):
         super(FaviconHandler, self).__init__(data_dir)
 
     def handle(self, attack_event):
-        response_header = "HTTP/1.1 200 OK\r\n"
-        response_header += "Connection: close\r\nContent-Type: image/x-icon;"
         with open(os.path.join(self.data_dir, 'favicon/favicon.ico'), 'r') as favicon:
             data = favicon.read()
-        response_header += "Content-Length: %s\r\n\r\n" % len(data)
-        attack_event.response = response_header + data
+            attack_event.http_request.set_response(data, headers=(('Content-Type, image/x-icon'),))
+
