@@ -17,16 +17,15 @@
 
 import os
 
+from glastopf.modules.handlers import base_emulator
+
 from jinja2 import Environment, FileSystemLoader
 
 
-package_directory = os.path.dirname(os.path.abspath(__file__))
-
-
-class SurfaceCreator(object):
-
-    def __init__(self):
-        self.template_env = Environment(loader=FileSystemLoader(os.path.join(package_directory, "templates")))
+class SurfaceCreator(base_emulator.BaseEmulator):
+    def __init__(self, data_dir):
+        super(SurfaceCreator, self).__init__(data_dir)
+        self.template_env = Environment(loader=FileSystemLoader(os.path.join(self.data_dir, "templates")))
 
     def get_index(self, title="Title Title", target="/index", body="Some Body", footer="Footer Text"):
         template = self.template_env.get_template('index.html')
